Probability mass function, distribution function, quantile function, random generation and sample estimation for two discrete skew Laplace distributions on integers. The skew discrete Laplace distributions here considered are that proposed by Kozubowski and Inusah (2006), henceforth referred to as DSL, and the alternative one proposed by Barbiero (2014), henceforth ADSL.
Arguments
Details
Package:
DiscreteLaplace
Type:
Package
Version:
1.1.1
Date:
2016-04-29
License:
GPL
LazyLoad:
yes
References
T. J. Kozubowski, S. Inusah (2006) A skew Laplace distribution on integers, Annals of the Institute of Statistical Mathematics, 58: 555-571, http://dx.doi.org/10.1007/s10463-005-0029-1